@@ -1,5 +1,5 @@
 package App::Provision::Mysql;
-$App::Provision::Mysql::VERSION = '0.03';
+$App::Provision::Mysql::VERSION = '0.04';
 BEGIN {
   $App::Provision::Mysql::AUTHORITY = 'cpan:GENE';
 }
@@ -7,6 +7,11 @@ use strict;
 use warnings;
 use parent qw( App::Provision::Tiny );
 
+sub deps
+{
+    return qw( homebrew );
+}
+
 sub meet
 {
     my $self = shift;
@@ -39,7 +44,7 @@ App::Provision::Mysql
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
