@@ -1,5 +1,5 @@
 package App::Provision::Sequelpro;
-$App::Provision::Sequelpro::VERSION = '0.03';
+$App::Provision::Sequelpro::VERSION = '0.04';
 BEGIN {
   $App::Provision::Sequelpro::AUTHORITY = 'cpan:GENE';
 }
@@ -7,6 +7,11 @@ use strict;
 use warnings;
 use parent qw( App::Provision::Tiny );
 
+sub deps
+{
+    return qw( wget );
+}
+
 sub condition
 {
     my $self = shift;
@@ -48,7 +53,7 @@ App::Provision::Sequelpro
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
