@@ -1,5 +1,5 @@
 package App::Provision::Ssh;
-$App::Provision::Ssh::VERSION = '0.03';
+$App::Provision::Ssh::VERSION = '0.04';
 BEGIN {
   $App::Provision::Ssh::AUTHORITY = 'cpan:GENE';
 }
@@ -14,11 +14,8 @@ sub condition
     die "Program '$self->{program}' must include --keytype and --keyname\n"
         unless $self->{keytype} && $self->{keyname};
 
-    # Set the keyfile attribute.
-    $self->{keyfile} = sprintf '%s/.ssh/id_%s-%s', $ENV{HOME},
-        $self->{keytype}, $self->{keyname};
-
-    my $condition = -e $self->{keyfile};
+    my $file = $self->_keyfile();
+    my $condition = -e $file;
     warn $self->{program}, ' is', ($condition ? '' : "n't"), " installed\n";
 
     return $condition ? 1 : 0;
@@ -27,13 +24,26 @@ sub condition
 sub meet
 {
     my $self = shift;
+
+    my $file = $self->_keyfile();
+
     $self->recipe(
-      [ 'ssh-keygen', '-t', $self->{keytype}, '-f', $self->{keyfile} ],
-      [ "cat $self->{keyfile}.pub | tr -d '\n' | pbcopy" ],
+      [ 'mkdir', '.ssh' ],
+      [ 'chmod', '700', '.ssh' ],
+      [ 'ssh-keygen', '-t', $self->{keytype}, '-f', $file ],
+      [ "cat $ENV{HOME}/.ssh/$file.pub | tr -d '\n' | pbcopy" ],
       [ 'echo', '* Now paste your public key into https://github.com/settings/ssh *' ],
     );
 }
 
+sub _keyfile
+{
+    # Set the keyfile attribute.
+    my $self = shift;
+    return sprintf '%s/.ssh/id_%s-%s', $ENV{HOME},
+        $self->{keytype}, $self->{keyname};
+}
+
 1;
 
 __END__
@@ -48,7 +58,7 @@ App::Provision::Ssh
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
